<?php

namespace Drupal\ekan_core\Service;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Component\Utility\Html;
use Drupal\Core\Entity\FieldableEntityInterface;
use Drupal\node\NodeInterface;
use Drupal\taxonomy\TermInterface;

/**
 * Service class for figuring out the correct icon for an entity.
 */
class EkanIconHandler {

  /**
   * Return the <i> icon for an entity.
   */
  public function getIconForEntity(EntityInterface $entity) {
    if ($entity instanceof FieldableEntityInterface && $entity->hasField('field_icon_char_code') && !$entity->get('field_icon_char_code')->isEmpty()) {
      $icon_unicode = $entity->get('field_icon_char_code')->getString();
      $icon_markup = "<i class='icon-dkan'>&#x{$icon_unicode};</i>";
    }
    elseif ($entity instanceof TermInterface || $entity instanceof NodeInterface) {
      $icon_class = 'icon-dkan-' . strtolower(Html::cleanCssIdentifier($entity->bundle()));
      $icon_markup = '<i class="' . $icon_class . '"></i>';
    }
    else {
      $icon_class = 'icon-dkan-' . strtolower(Html::cleanCssIdentifier($entity->getEntityTypeId()));
      $icon_markup = '<i class="' . $icon_class . '"></i>';
    }

    return $icon_markup;
  }

}
