<?php

namespace Drupal\ekan_visuals\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\ekan_core\Entity\EkanResourceEntity;

/**
 * Field formatter to Visualisation.
 *
 * @FieldFormatter(
 *  id = "visualisation_formatter",
 *  label = @Translation("Ekan Visualisation"),
 *  field_types = {"string_long"}
 * )
 */
class VisualisationFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    $options = parent::defaultSettings();

    $options['display_based_on_show_dataset_config'] = FALSE;
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);

    $form['display_based_on_show_dataset_config'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Check against "Show on dataset" setting of visualisation'),
      '#description' => $this->t('If not ticked, it will render the visualisation and ignore the "show visualisation on dataset" setting.'),
      '#default_value' => $this->getSetting('display_based_on_show_dataset_config'),
    ];

    return $form;
  }

  /**
   * Renders a pdf selected plugin for the resource type.
   *
   * @param \Drupal\Core\Field\FieldItemListInterface $items
   *   The collection of field items.
   * @param string $langcode
   *   The language code.
   *
   * @return array
   *   A renderable array.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    $value = $items->getValue()[0]['value'];
    if (!$value) {
      return [];
    }
    $entity = $items->getEntity();
    if (!($entity instanceof EkanResourceEntity)) {
      return [];
    }
    $value = json_decode($value, TRUE);
    /** @var \Drupal\ekan_visuals\EkanVisualisationManager $plugin_manager */
    $plugin_manager = \Drupal::service('plugin.manager.ekan_visualisation');
    foreach ($value as $plugin_id => $settings) {
      /** @var \Drupal\ekan_visuals\Plugin\EkanVisualisation\EkanVisualisationInterface $visualisation_plugin */
      $visualisation_plugin = $plugin_manager->createInstance($plugin_id);
      // Check if we should check for "show on dataset" config and
      // "show on dataset" is true for visualisation plugin.
      if ($this->getSetting('display_based_on_show_dataset_config') && $settings['settings']['show_on_dataset']) {
        $elements[] = $visualisation_plugin->visualise($entity, $settings['settings']);
      }
      // If we don't care of dataset based on config, then render anyway.
      elseif (!$this->getSetting('display_based_on_show_dataset_config')) {
        $elements[] = $visualisation_plugin->visualise($entity, $settings['settings']);
      }
    }

    return $elements;
  }

}
